@@ -10,7 +10,7 @@ import board
 import adafruit_ahtx0
 
 # Create sensor object, communicating over the board's default I2C bus
-i2c = board.I2C()
+i2c = board.I2C()  # uses board.SCL and board.SDA
 sensor = adafruit_ahtx0.AHTx0(i2c)
 
 while True:
